# OrderLineItemCategory

The category for the Order Line Item, to indicate a product sale or return. 

## Enum

* `SALES` (value: `'Sales'`)

* `RETURN` (value: `'Return'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


